Atom class

Constructors

Atom(String atomLabel, int id, double x, double y, {int numHgens = 0, int fontSize = 10})

Properties

atomLabel String
getter/setter pair
fontSize int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id int
getter/setter pair
numHgens int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x double
getter/setter pair
y double
getter/setter pair

Methods

copyWith() Atom
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited