Bond class

Available extensions

Constructors

Bond(BondStyle bondStyle, int beginAtom, int endAtom)

Properties

beginAtom int
getter/setter pair
bondStyle BondStyle
getter/setter pair
endAtom int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isDoubleBond bool
no setter
isSingleBond bool
no setter
isTripleBond bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

bAtom(Set<Atom> atoms) Atom

Available on Bond, provided by the BondEx extension

bondVector(Set<Atom> atoms) → Vector2

Available on Bond, provided by the BondEx extension

bPos(Set<Atom> atoms) → Vector2

Available on Bond, provided by the BondEx extension

copyWith() Bond
eAtom(Set<Atom> atoms) Atom

Available on Bond, provided by the BondEx extension

ePos(Set<Atom> atoms) → Vector2

Available on Bond, provided by the BondEx extension

fixDoubleBondPosision(Set<Atom> atoms, Set<Bond> bonds) → void

Available on Bond, provided by the BondEx extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited