BoundingBox class

Constructors

BoundingBox(double x, double y, double width, double height)
BoundingBox.fromDoublelist(List<double> list)

Properties

hashCode int
The hash code for this object.
no setterinherited
height double
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double
getter/setter pair
x double
getter/setter pair
y double
getter/setter pair

Methods

copyWith() BoundingBox
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator +(BoundingBox other) BoundingBox
operator ==(Object other) bool
The equality operator.
inherited