StructurePage class

Constructors

StructurePage({required String name, required Set<Fragment> fragments, required BoundingBox boundingBox})

Properties

boundingBox BoundingBox
getter/setter pair
fragments Set<Fragment>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited